==> qtjambi-help-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiHelp/QHelpFilterData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpfilterdata.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiHelp/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpFilterData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpFilterData")
    QHelpFilterData *_ptr = reinterpret_cast<QHelpFilterData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpFilterData()
void __qt_construct_QHelpFilterData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpFilterData()")
    Q_UNUSED(__java_arguments)
    QHelpFilterData *__qt_this = new(__qtjambi_ptr) QHelpFilterData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHelpFilterData(QHelpFilterData)
void __qt_construct_QHelpFilterData_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpFilterData(QHelpFilterData)")
    jobject other0 = __java_arguments[0].l;
    const QHelpFilterData& __qt_other0 = qtjambi_cast<const QHelpFilterData& >(__jni_env, other0);
    QHelpFilterData *__qt_this = new(__qtjambi_ptr) QHelpFilterData(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QHelpFilterData
void __qt_destruct_QHelpFilterData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpFilterData")
    reinterpret_cast<QHelpFilterData*>(ptr)->~QHelpFilterData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpFilterData::QHelpFilterData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_initialize_1native__Lio_qt_help_QHelpFilterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpFilterData::QHelpFilterData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpFilterData_0, sizeof(QHelpFilterData), typeid(QHelpFilterData), false, &deleter_QHelpFilterData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::QHelpFilterData(QHelpFilterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_initialize_1native__Lio_qt_help_QHelpFilterData_2Lio_qt_help_QHelpFilterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpFilterData::QHelpFilterData(QHelpFilterData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpFilterData_1, sizeof(QHelpFilterData), typeid(QHelpFilterData), false, &deleter_QHelpFilterData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::components()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_components_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::components()const", __qt_this)
        QStringList __qt_return_value = __qt_this->components();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpFilterData::operator=(QHelpFilterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_assign_1native_1cref_1QHelpFilterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::operator=(QHelpFilterData)", __qt_this)
        const QHelpFilterData& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpFilterData>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::operator==(QHelpFilterData)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_equals_1native_1cref_1QHelpFilterData_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::operator==(QHelpFilterData)const", __qt_this)
        const QHelpFilterData& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpFilterData>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpFilterData::setComponents(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_setComponents_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject components0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::setComponents(QStringList)", __qt_this)
        const QStringList&  __qt_components0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, components0);
        __qt_this->setComponents(__qt_components0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::setVersions(QList<QVersionNumber>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_setVersions_1native_1cref_1QList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject versions0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::setVersions(QList<QVersionNumber>)", __qt_this)
        const QList<QVersionNumber>&  __qt_versions0 = qtjambi_cast<const QList<QVersionNumber>& >(__jni_env, __qtjambi_scope, versions0);
        __qt_this->setVersions(__qt_versions0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::swap(QHelpFilterData&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_swap_1native_1ref_1QHelpFilterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::swap(QHelpFilterData&)", __qt_this)
        QHelpFilterData& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHelpFilterData>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::versions()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_versions_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::versions()const", __qt_this)
        QList<QVersionNumber> __qt_return_value = __qt_this->versions();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpFilterData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpFilterData>("QHelpFilterData", "io/qt/help/QHelpFilterData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpFilterData, {
        ConstructorInfo(&__qt_construct_QHelpFilterData_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpFilterData_1, "Lio/qt/help/QHelpFilterData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpFilterData);
    registerMetaType<QHelpFilterData>("QHelpFilterData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiHelp/QHelpFilterData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpfilterdata.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiHelp/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpFilterData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpFilterData")
    QHelpFilterData *_ptr = reinterpret_cast<QHelpFilterData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpFilterData()
void __qt_construct_QHelpFilterData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpFilterData()")
    Q_UNUSED(__java_arguments)
    QHelpFilterData *__qt_this = new(__qtjambi_ptr) QHelpFilterData();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHelpFilterData::QHelpFilterData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_initialize_1native__Lio_qt_help_QHelpFilterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpFilterData::QHelpFilterData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpFilterData, sizeof(QHelpFilterData), typeid(QHelpFilterData), false, &deleter_QHelpFilterData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpFilterData(QHelpFilterData)
void __qt_construct_QHelpFilterData_cref_QHelpFilterData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpFilterData(QHelpFilterData)")
    jobject other0 = __java_arguments[0].l;
    const QHelpFilterData& __qt_other0 = qtjambi_cast<const QHelpFilterData& >(__jni_env, other0);
    QHelpFilterData *__qt_this = new(__qtjambi_ptr) QHelpFilterData(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpFilterData::QHelpFilterData(QHelpFilterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_initialize_1native__Lio_qt_help_QHelpFilterData_2Lio_qt_help_QHelpFilterData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpFilterData::QHelpFilterData(QHelpFilterData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpFilterData_cref_QHelpFilterData, sizeof(QHelpFilterData), typeid(QHelpFilterData), false, &deleter_QHelpFilterData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHelpFilterData
void __qt_destruct_QHelpFilterData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpFilterData")
    reinterpret_cast<QHelpFilterData*>(ptr)->~QHelpFilterData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpFilterData::components()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_components_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::components()const", __qt_this)
        QStringList __qt_return_value = __qt_this->components();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpFilterData::operator=(QHelpFilterData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_assign_1native_1cref_1QHelpFilterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::operator=(QHelpFilterData)", __qt_this)
        const QHelpFilterData& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpFilterData>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::operator==(QHelpFilterData)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_equals_1native_1cref_1QHelpFilterData_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::operator==(QHelpFilterData)const", __qt_this)
        const QHelpFilterData& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpFilterData>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpFilterData::setComponents(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_setComponents_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject components0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::setComponents(QStringList)", __qt_this)
        const QStringList&  __qt_components0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, components0);
        __qt_this->setComponents(__qt_components0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::setVersions(QList<QVersionNumber>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_setVersions_1native_1cref_1QList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject versions0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::setVersions(QList<QVersionNumber>)", __qt_this)
        const QList<QVersionNumber>&  __qt_versions0 = qtjambi_cast<const QList<QVersionNumber>& >(__jni_env, __qtjambi_scope, versions0);
        __qt_this->setVersions(__qt_versions0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::swap(QHelpFilterData&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_swap_1native_1ref_1QHelpFilterData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::swap(QHelpFilterData&)", __qt_this)
        QHelpFilterData& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHelpFilterData>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpFilterData::versions()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_versions_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpFilterData::versions()const", __qt_this)
        QList<QVersionNumber> __qt_return_value = __qt_this->versions();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpFilterData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpFilterData *__qt_this = QtJambiAPI::objectFromNativeId<QHelpFilterData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpFilterData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpFilterData>("QHelpFilterData", "io/qt/help/QHelpFilterData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpFilterData, {
        ConstructorInfo(&__qt_construct_QHelpFilterData, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpFilterData_cref_QHelpFilterData, "Lio/qt/help/QHelpFilterData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpFilterData);
    registerMetaType<QHelpFilterData>("QHelpFilterData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
